# Collection framework

### This is little application to find uniq count in strings

## **usage**:

--string **your string**
(find uniq count in string)

--file **path to file**
(find uniq count in file)